==> imsdk-plus-6.9.3557-sources.jar: com/tencent/imsdk/message/MessageKey.java <==
package com.tencent.imsdk.message;

import java.io.Serializable;

public class MessageKey implements Serializable {
    private String messageID;
    private int messageType;
    private boolean isMessageSender;
    private String senderUserID;
    private long senderTinyID;
    private String receiverUserID;
    private long receiverTinyID;
    private String groupID;
    private long clientTime;
    private long serverTime;
    private long seq;
    private long random;

    public String getMessageID() {
        return messageID;
    }

    public int getMessageType() {
        return messageType;
    }

    public boolean isMessageSender() {
        return isMessageSender;
    }

    public void setIsMessageSender(boolean isMessageSender) {
        this.isMessageSender = isMessageSender;
    }

    public String getSenderUserID() {
        return senderUserID;
    }

    public String getReceiverUserID() {
        return receiverUserID;
    }

    public String getGroupID() {
        return groupID;
    }

    public long getClientTime() {
        return clientTime;
    }

    public long getServerTime() {
        return serverTime;
    }

    public long getSeq() {
        return seq;
    }

    public long getRandom() {
        return random;
    }

    public void setMessageID(String messageID) {
        this.messageID = messageID;
    }

    public void setMessageType(int messageType) {
        this.messageType = messageType;
    }

    public void setSenderUserID(String senderUserID) {
        this.senderUserID = senderUserID;
    }

    public void setReceiverUserID(String receiverUserID) {
        this.receiverUserID = receiverUserID;
    }

    public void setGroupID(String groupID) {
        this.groupID = groupID;
    }

    public void setClientTime(long clientTime) {
        this.clientTime = clientTime;
    }

    public void setServerTime(long serverTime) {
        this.serverTime = serverTime;
    }

    public void setSeq(long seq) {
        this.seq = seq;
    }

    public void setRandom(long random) {
        this.random = random;
    }

    public long getSenderTinyID() {
        return senderTinyID;
    }

    public void setSenderTinyID(long senderTinyID) {
        this.senderTinyID = senderTinyID;
    }

    public long getReceiverTinyID() {
        return receiverTinyID;
    }

    public void setReceiverTinyID(long receiverTinyID) {
        this.receiverTinyID = receiverTinyID;
    }

    @Override
    public String toString() {
        StringBuilder stringBuilder = new StringBuilder();

        stringBuilder.append("MessageKey--->")
                .append("messageID:").append(messageID).append(", messageType:").append(messageType)
                .append(", isMessageSender:").append(isMessageSender).append(", senderUserID:").append(senderUserID)
                .append(", receiverUserID:").append(receiverUserID).append(", groupID:").append(groupID)
                .append(", clientTime:").append(clientTime).append(", serverTime:").append(serverTime)
                .append(", seq:").append(seq).append(", random:").append(random);

        return stringBuilder.toString();
    }
}

==> imsdk-plus-7.9.5680-sources.jar: com/tencent/imsdk/message/MessageKey.java <==
package com.tencent.imsdk.message;

import java.io.Serializable;

public class MessageKey implements Serializable {
    private String messageID;
    private int messageType;
    private boolean isMessageSender;
    private String senderUserID;
    private long senderTinyID;
    private String receiverUserID;
    private long receiverTinyID;
    private String groupID;
    private long clientTime;
    private long serverTime;
    private long seq;
    private long random;

    public String getMessageID() {
        return messageID;
    }

    public int getMessageType() {
        return messageType;
    }

    public boolean isMessageSender() {
        return isMessageSender;
    }

    public void setIsMessageSender(boolean isMessageSender) {
        this.isMessageSender = isMessageSender;
    }

    public String getSenderUserID() {
        return senderUserID;
    }

    public String getReceiverUserID() {
        return receiverUserID;
    }

    public String getGroupID() {
        return groupID;
    }

    public long getClientTime() {
        return clientTime;
    }

    public long getServerTime() {
        return serverTime;
    }

    public long getSeq() {
        return seq;
    }

    public long getRandom() {
        return random;
    }

    public void setMessageID(String messageID) {
        this.messageID = messageID;
    }

    public void setMessageType(int messageType) {
        this.messageType = messageType;
    }

    public void setSenderUserID(String senderUserID) {
        this.senderUserID = senderUserID;
    }

    public void setReceiverUserID(String receiverUserID) {
        this.receiverUserID = receiverUserID;
    }

    public void setGroupID(String groupID) {
        this.groupID = groupID;
    }

    public void setClientTime(long clientTime) {
        this.clientTime = clientTime;
    }

    public void setServerTime(long serverTime) {
        this.serverTime = serverTime;
    }

    public void setSeq(long seq) {
        this.seq = seq;
    }

    public void setRandom(long random) {
        this.random = random;
    }

    public long getSenderTinyID() {
        return senderTinyID;
    }

    public void setSenderTinyID(long senderTinyID) {
        this.senderTinyID = senderTinyID;
    }

    public long getReceiverTinyID() {
        return receiverTinyID;
    }

    public void setReceiverTinyID(long receiverTinyID) {
        this.receiverTinyID = receiverTinyID;
    }

    @Override
    public String toString() {
        StringBuilder stringBuilder = new StringBuilder();

        stringBuilder.append("MessageKey--->")
            .append("messageID:")
            .append(messageID)
            .append(", messageType:")
            .append(messageType)
            .append(", isMessageSender:")
            .append(isMessageSender)
            .append(", senderUserID:")
            .append(senderUserID)
            .append(", receiverUserID:")
            .append(receiverUserID)
            .append(", groupID:")
            .append(groupID)
            .append(", clientTime:")
            .append(clientTime)
            .append(", serverTime:")
            .append(serverTime)
            .append(", seq:")
            .append(seq)
            .append(", random:")
            .append(random);

        return stringBuilder.toString();
    }
}
